@@ -25,7 +25,7 @@ Implementation Notes
 
 import displayio
 
-__version__ = "1.2.7"
+__version__ = "1.2.8"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_ST7735.git"
 
 _INIT_SEQUENCE = (
@@ -52,5 +52,5 @@ _INIT_SEQUENCE = (
 class ST7735(displayio.Display):
     """ST7735 driver"""
 
-    def __init__(self, bus, **kwargs):
+    def __init__(self, bus: displayio.FourWire, **kwargs) -> None:
         super().__init__(bus, _INIT_SEQUENCE, **kwargs)
