@@ -24,7 +24,7 @@ display_bus = displayio.FourWire(
 display = ST7735(display_bus, width=128, height=128)
 
 # Make the display context
-splash = displayio.Group(max_size=10)
+splash = displayio.Group()
 display.show(splash)
 
 color_bitmap = displayio.Bitmap(128, 128, 1)
